Crate corevm_host

Crate corevm_host 

Public API for CoreVM builders.

This API is shared between the builders and the CoreVM service itself.

Modules

flags
Host-call flags.
fs
CoreVM FS that uses preimage store as a backend.

Structs

Arg
Command line argument.
AudioMode
Audio monitor output mode.
ConsoleChunk
A chunk of console output.
ConsoleChunks
Several chunks of console output.
CoreVmExtrinsics
CoreVM-specific extrinsics.
CoreVmOutput
CoreVM-specific work output.
CoreVmPayload
CoreVM-specific work payload.
ExecEnv
Guest execution environment.
InputChunk
Input chunk.
InputStreams
A set of input streams.
KernelFd
In-kernel file descriptor state.
KernelState
The state of the Linux kernel syscall layer.
LenAndSourceOutcome
The base types for outcomes that encodes Option<(u32, u32)>, that contains length and source, as a single 64-bit value. None is encoded as u64::MAX, and thus length must be less than u32::MAX.
MessageQueue
Message queue in service storage.
OutgoingServiceMessage
Outgoing inter-service message.
OutputBuffers
CoreVM output stream buffers.
PageInfo
Memory page metadata.
PageNum
Page number.
Range
RangeSet
RecvHostMessageOutcome
The return type of recv_host_message host-call (message length and source).
RecvMessageOutcome
The return type of recv_message host-call (message length and source).
RecvTransactionOutcome
The return type of recv_transaction host-call (payload length and source).
ServiceMessage
A message from another service.
VideoMode
Video monitor output mode.
VideoModeOptions
Optional video mode parameters.
VmOutput
The specification of the VM’s output data.
VmSpec
Same as CoreVmOutput but only includes the data necessary to continue program execution.
VmState
Inner VM state.

Enums

AudioSampleFormat
The format of the samples emitted via yield_audio_samples.
CoreVmInstruction
Instruction to send to the CoreVM service.
InputVideoFrameFormat
The format of the input video frames accesed via read_video_frame.
Outcome
The result code returned by CoreVM service.
OutputStream
Output stream identifier.
StorageKey
Storage keys used by CoreVM.
VideoFrameFormat
The format of the frames emitted via [yield_video_frame].

Constants

PAGE_SIZE
Inner VM page size.

Traits

PageSegmentOps
An import/export segment that stores an inner VM page and its number.

Type Aliases

GuestId
CoreVM guest identifier.