pub struct ReadAudioFrames(/* private fields */);Expand description
read_audio_frames host-call flags.
Implementations
Sourceimpl ReadAudioFrames
impl ReadAudioFrames
Sourcepub const NON_BLOCKING: ReadAudioFrames
pub const NON_BLOCKING: ReadAudioFrames
Makes the call non-blocking.
Sourceimpl ReadAudioFrames
impl ReadAudioFrames
Sourcepub const fn empty() -> ReadAudioFrames
pub const fn empty() -> ReadAudioFrames
Get a flags value with all bits unset.
Sourcepub const fn all() -> ReadAudioFrames
pub const fn all() -> ReadAudioFrames
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<ReadAudioFrames>
pub const fn from_bits(bits: u64) -> Option<ReadAudioFrames>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> ReadAudioFrames
pub const fn from_bits_truncate(bits: u64) -> ReadAudioFrames
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> ReadAudioFrames
pub const fn from_bits_retain(bits: u64) -> ReadAudioFrames
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ReadAudioFrames>
pub fn from_name(name: &str) -> Option<ReadAudioFrames>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ReadAudioFrames) -> bool
pub const fn intersects(&self, other: ReadAudioFrames) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ReadAudioFrames) -> bool
pub const fn contains(&self, other: ReadAudioFrames) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ReadAudioFrames)
pub fn insert(&mut self, other: ReadAudioFrames)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ReadAudioFrames)
pub fn remove(&mut self, other: ReadAudioFrames)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ReadAudioFrames)
pub fn toggle(&mut self, other: ReadAudioFrames)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ReadAudioFrames, value: bool)
pub fn set(&mut self, other: ReadAudioFrames, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ReadAudioFrames) -> ReadAudioFrames
pub const fn intersection(self, other: ReadAudioFrames) -> ReadAudioFrames
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ReadAudioFrames) -> ReadAudioFrames
pub const fn union(self, other: ReadAudioFrames) -> ReadAudioFrames
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ReadAudioFrames) -> ReadAudioFrames
pub const fn difference(self, other: ReadAudioFrames) -> ReadAudioFrames
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ReadAudioFrames,
) -> ReadAudioFrames
pub const fn symmetric_difference( self, other: ReadAudioFrames, ) -> ReadAudioFrames
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ReadAudioFrames
pub const fn complement(self) -> ReadAudioFrames
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ReadAudioFrames
impl ReadAudioFrames
Sourcepub const fn iter(&self) -> Iter<ReadAudioFrames>
pub const fn iter(&self) -> Iter<ReadAudioFrames>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ReadAudioFrames>
pub const fn iter_names(&self) -> IterNames<ReadAudioFrames>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.