pub struct InputChunk {
pub video: Bytes,
pub audio: Bytes,
pub console: Bytes,
pub host_messages: Vec<Bytes>,
}Expand description
Input chunk.
Contains data for each stream.
Fields
video: Bytesaudio: Bytesconsole: Byteshost_messages: Vec<Bytes>Messages exchanged between the service and the host (builder/monitor etc.).
Implementations
Sourceimpl InputChunk
impl InputChunk
Sourcepub fn decode_signed(input: Bytes, key: &VerificationKey) -> Result<Self, Error>
pub fn decode_signed(input: Bytes, key: &VerificationKey) -> Result<Self, Error>
Decode signed input chunk.
Checks the signature at the end of the input against the provided key before doing the usual decoding.
Sourcepub fn decode_multiple_signed(
extrinsic: Bytes,
key: &VerificationKey,
) -> Result<Vec<Self>, Error>
pub fn decode_multiple_signed( extrinsic: Bytes, key: &VerificationKey, ) -> Result<Vec<Self>, Error>
Decode multiple signed chunks from the extrinsic.