InputStreams

Struct InputStreams 

pub struct InputStreams(/* private fields */);
A set of input streams.

Used in poll host-call.

Implementations

Source

impl InputStreams

Source

impl InputStreams

pub const fn empty() -> InputStreams

Get a flags value with all bits unset.

pub const fn all() -> InputStreams

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<InputStreams>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> InputStreams

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> InputStreams

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<InputStreams>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: InputStreams) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: InputStreams) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: InputStreams)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: InputStreams)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: InputStreams)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: InputStreams, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: InputStreams) -> InputStreams

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: InputStreams) -> InputStreams

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: InputStreams) -> InputStreams

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: InputStreams) -> InputStreams

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> InputStreams

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl InputStreams

pub const fn iter(&self) -> Iter<InputStreams>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<InputStreams>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.