Public API for CoreVM builders.
This API is shared between the builders and the CoreVM service itself.
Modules
Structs
- Arg
- Command line argument.
- Audio
Mode - Audio monitor output mode.
- Console
Chunk - A chunk of console output.
- Console
Chunks - Several chunks of console output.
- Core
VmExtrinsics - CoreVM-specific extrinsics.
- Core
VmOutput - CoreVM-specific work output.
- Core
VmPayload - CoreVM-specific work payload.
- ExecEnv
- Guest execution environment.
- Input
Chunk - Input chunk.
- Input
Streams - A set of input streams.
- Kernel
Fd - In-kernel file descriptor state.
- Kernel
State - The state of the Linux kernel syscall layer.
- LenAnd
Source Outcome - The base types for outcomes that encodes
Option<(u32, u32)>, that contains length and source, as a single 64-bit value.Noneis encoded asu64::MAX, and thus length must be less thanu32::MAX. - Message
Queue - Message queue in service storage.
- Outgoing
Service Message - Outgoing inter-service message.
- Output
Buffers - CoreVM output stream buffers.
- Page
Info - Memory page metadata.
- PageNum
- Page number.
- Range
- Range
Set - Recv
Host Message Outcome - The return type of
recv_host_messagehost-call (message length and source). - Recv
Message Outcome - The return type of
recv_messagehost-call (message length and source). - Recv
Transaction Outcome - The return type of
recv_transactionhost-call (payload length and source). - Service
Message - A message from another service.
- Video
Mode - Video monitor output mode.
- Video
Mode Options - Optional video mode parameters.
- VmOutput
- The specification of the VM’s output data.
- VmSpec
- Same as
CoreVmOutputbut only includes the data necessary to continue program execution. - VmState
- Inner VM state.
Enums
- Audio
Sample Format - The format of the samples emitted via
yield_audio_samples. - Core
VmInstruction - Instruction to send to the CoreVM service.
- Input
Video Frame Format - The format of the input video frames accesed via
read_video_frame. - Outcome
- The result code returned by CoreVM service.
- Output
Stream - Output stream identifier.
- Storage
Key - Storage keys used by CoreVM.
- Video
Frame Format - The format of the frames emitted via [
yield_video_frame].
Constants
- PAGE_
SIZE - Inner VM page size.
Traits
- Page
Segment Ops - An import/export segment that stores an inner VM page and its number.
Type Aliases
- GuestId
- CoreVM guest identifier.