pub enum InputVideoFrameFormat {
Rgb888 = 0,
}Expand description
The format of the input video frames accesed via read_video_frame.
Variants
Rgb888 = 0
Each pixel is encoded using red, green, blue components, each component occupies 8 bits. The pixels are stored in row-major order.