pub struct InputStreams(/* private fields */);Expand description
A set of input streams.
Used in poll host-call.
Implementations
Sourceimpl InputStreams
impl InputStreams
pub const SERVICE_MESSAGES: InputStreams
pub const HOST_MESSAGES: InputStreams
pub const CONSOLE: InputStreams
pub const VIDEO: InputStreams
pub const AUDIO: InputStreams
pub const TRANSACTIONS: InputStreams
Sourceimpl InputStreams
impl InputStreams
Sourcepub const fn empty() -> InputStreams
pub const fn empty() -> InputStreams
Get a flags value with all bits unset.
Sourcepub const fn all() -> InputStreams
pub const fn all() -> InputStreams
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<InputStreams>
pub const fn from_bits(bits: u32) -> Option<InputStreams>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> InputStreams
pub const fn from_bits_truncate(bits: u32) -> InputStreams
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> InputStreams
pub const fn from_bits_retain(bits: u32) -> InputStreams
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<InputStreams>
pub fn from_name(name: &str) -> Option<InputStreams>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: InputStreams) -> bool
pub const fn intersects(&self, other: InputStreams) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: InputStreams) -> bool
pub const fn contains(&self, other: InputStreams) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: InputStreams)
pub fn insert(&mut self, other: InputStreams)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: InputStreams)
pub fn remove(&mut self, other: InputStreams)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: InputStreams)
pub fn toggle(&mut self, other: InputStreams)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: InputStreams, value: bool)
pub fn set(&mut self, other: InputStreams, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: InputStreams) -> InputStreams
pub const fn intersection(self, other: InputStreams) -> InputStreams
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: InputStreams) -> InputStreams
pub const fn union(self, other: InputStreams) -> InputStreams
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: InputStreams) -> InputStreams
pub const fn difference(self, other: InputStreams) -> InputStreams
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: InputStreams) -> InputStreams
pub const fn symmetric_difference(self, other: InputStreams) -> InputStreams
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> InputStreams
pub const fn complement(self) -> InputStreams
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl InputStreams
impl InputStreams
Sourcepub const fn iter(&self) -> Iter<InputStreams>
pub const fn iter(&self) -> Iter<InputStreams>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InputStreams>
pub const fn iter_names(&self) -> IterNames<InputStreams>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.