pub struct VideoModeOptions(/* private fields */);Expand description
Optional video mode parameters.
Implementations
Sourceimpl VideoModeOptions
impl VideoModeOptions
Sourcepub const fn new() -> VideoModeOptions
pub const fn new() -> VideoModeOptions
Create new empty set of options.
Sourcepub const fn set_quantization_level(&mut self, level: u8)
pub const fn set_quantization_level(&mut self, level: u8)
Set video codec quantization level.
Non-zero value makes video encoding lossy. Typical value is between 0 and 4.
Sourcepub const fn quantization_level(&self) -> u8
pub const fn quantization_level(&self) -> u8
Returns video codec quantization level.
Sourcepub const fn set_chroma_subsampling(&mut self, value: bool)
pub const fn set_chroma_subsampling(&mut self, value: bool)
Enables/disables 4:2:0 chroma subsampling.
Chroma subsampling makes video encoding lossy.
Sourcepub const fn chroma_subsampling(&self) -> bool
pub const fn chroma_subsampling(&self) -> bool
Returns true when chroma subsampling is enabled.
Sourcepub const fn set_raw(&mut self, value: bool)
pub const fn set_raw(&mut self, value: bool)
Sets raw mode.
When enabled, video frames are written in the original format without encoding.
This is useful when running the code in a RISCV interpreter.
pub const fn as_u64(self) -> u64